@@ -313,8 +313,6 @@ extern unsigned int  ATI_API_CALL KCL_IsPageInHighMem(void* page);
 
 extern void*         ATI_API_CALL KCL_GetHighMemory(void);
 extern int           ATI_API_CALL KCL_GetErrorCode(KCL_ENUM_ErrorCode errcode);
-extern void          ATI_API_CALL KCL_GlobalKernelLock(void);
-extern void          ATI_API_CALL KCL_GlobalKernelUnlock(void);
 extern int           ATI_API_CALL KCL_PosixSecurityCapCheck(KCL_ENUM_PosixSecurityCap cap);
 extern int           ATI_API_CALL KCL_PosixSecurityCapSetIPCLock(unsigned int lock);
 extern unsigned long ATI_API_CALL KCL_GetAvailableRamPages(void);
