@@ -155,15 +155,22 @@ fi
 # ==============================================================
 # assing default location of linux kernel headers
 
-linuxincludes=/usr/src/linux/include
+linuxbuild=/usr/src/linux
+linuxsources=$linuxbuild
 
 # in /lib/modules/<kernel-version> there is a symlink for latest kernel
 # which calls "build" and points to the directory where modules were built.
+# On some distros some configuration-independent kernel headers can't be
+# found in "build" but in a different directory pointed to by a symlink
+# called "source".
 if [ -d /lib/modules/${uname_r}/build/include ]; then
     # just comment this line out if you already set an alternative location
-    linuxincludes=/lib/modules/${uname_r}/build/include
+    linuxbuild=/lib/modules/${uname_r}/build
+    linuxsources=/lib/modules/${uname_r}/source
 fi
 
+linuxincludes=$linuxbuild/include
+
 # ==============================================================
 # print some statistics, helpful for analyzing any build failures
 
@@ -397,12 +404,22 @@ fi
 
 COMPAT_ALLOC_USER_SPACE=compat_alloc_user_space
 
-src_file=$linuxincludes/../arch/x86/include/asm/compat.h
+for src_file in \
+    $linuxbuild/arch/x86/include/asm/compat.h \
+    $linuxsources/arch/x86/include/asm/compat.h \
+    $linuxbuild/include/asm-x86_64/compat.h \
+    $linuxsources/include/asm-x86_64/compat.h;
+do
+  if [ -e $src_file ];
+  then
+    break
+  fi
+done
 if [ ! -e $src_file ];
 then
-  echo "Warning:"                                                  >> $logfile
-  echo "kernel includes at $linuxincludes not found or incomplete" >> $logfile
-  echo "file: $src_file"                                           >> $logfile
+  echo "Warning: x86 compat.h not found in kernel headers"         >> $logfile
+  echo "neither arch/x86/include/asm/compat.h nor include/asm-x86_64/compat.h" >> $logfile
+  echo "could be found in $linuxbuild or $linuxsources"            >> $logfile
   echo ""                                                          >> $logfile
 else
   if [ `cat $src_file | grep -c arch_compat_alloc_user_space` -gt 0 ]
@@ -445,11 +462,13 @@ cd 2.6.x
 
 make clean
 
-echo 'This is a dummy file created to suppress this warning: could not find /lib/modules/fglrx/build_mod/2.6.x/.libfglrx_ip.a.GCC4.cmd for /lib/modules/fglrx/build_mod/2.6.x/libfglrx_ip.a.GCC4' > .lib${MODULE}_ip.a.GCC${GCC_MAJOR}.cmd
+echo 'This is a dummy file created to suppress this warning: could not find /lib/modules/fglrx/build_mod/2.6.x/.libfglrx_ip.a.cmd for /lib/modules/fglrx/build_mod/2.6.x/libfglrx_ip.a' > .lib${MODULE}_ip.a.cmd
 
+CFLAGS_MODULE="-DMODULE -DATI -DFGL -DPAGE_ATTR_FIX=$PAGE_ATTR_FIX -DCOMPAT_ALLOC_USER_SPACE=$COMPAT_ALLOC_USER_SPACE $def_smp $def_modversions"
 make CC=${CC} \
     LIBIP_PREFIX=$(echo "$LIBIP_PREFIX" | sed -e 's|^\([^/]\)|../\1|') \
-    MODFLAGS="-DMODULE -DATI -DFGL -DPAGE_ATTR_FIX=$PAGE_ATTR_FIX -DCOMPAT_ALLOC_USER_SPACE=$COMPAT_ALLOC_USER_SPACE $def_smp $def_modversions" \
+    MODFLAGS="$CFLAGS_MODULE" \
+    CFLAGS_MODULE="$CFLAGS_MODULE" \
     KVER=${uname_r} \
     PAGE_ATTR_FIX=$PAGE_ATTR_FIX \
     > tlog 2>&1 
